function [ t ECG N duration] = create_ECG(P, Q, R, S, T, PR, QT, ST, ...
    P_dur, QRS, BPM)

%Christopher Shih

%P
    %0.25 mV
%Q
    %0 mV
%R 
    %1.6 mV
%S 
    %0.25 R
%T
    %0.1-0.5 mV (0.25 mV) 
%PR
    %0.12 - 0.2 s  (0.16 s)
%QT
    %0.35-0.44 s   (0.40 s) 
%ST 
    %0.05-0.15s (0.10 s) 
%P
    %0.11 s
%QRS
    %0.09 s 
%sample @ 720, 2*Fs

Hz = BPM/60; 
duration = 1/Hz;
N = 1280; 
t = linspace(0, duration, N);

ECG = zeros(1,N); 
%P 
w = pi/P_dur ;
P_wave = P .*sin(w.*t);
P_len = round(P_dur/duration * N); 
ECG(1:P_len) = P_wave(1:P_len); 

%QRS
Q_slope = -Q/(QRS/4);
Q_delay = 0; 

R_slope = ( Q + R ) / (QRS / 2 ) + abs(Q_slope);
R_delay = QRS/4;

S_slope = -( R + S) / (QRS / 4) + abs(Q_slope) - R_slope;  
S_delay = 3*QRS/4;

Q_wave = Q_slope.*(t - Q_delay);
    
R_wave = R_slope.*(t - R_delay);
    for g = 1:N
        if R_wave(g) < 0
            R_wave(g) = 0 ;
        end
    end

S_wave = S_slope.*(t - S_delay);
    for g = 1:N
        if S_wave(g) > 0
            S_wave(g) = 0 ;
        end
    end
%{
    Plotting for QRS check
figure()
plot(Q_wave);
figure()
plot(R_wave);
figure()
plot(S_wave);
%}

QRS_wave = Q_wave + R_wave + S_wave; 

QRS_start = round((P_dur + PR)/duration * N);
QRS_end = round((P_dur + PR + QRS)/duration * N);

ECG(QRS_start:QRS_end) = QRS_wave(1:(QRS_end - QRS_start + 1 )); 

%T wave
T_dur = QT - QRS-(ST);
w = pi/T_dur ;
T_wave = T .*sin(w.*t);

T_start = round((P_dur + PR + QRS+ ST)/duration * N);
T_end = round((P_dur + PR + QRS + ST + T_dur)/duration * N);
ECG(T_start:T_end) = T_wave(1:T_end - T_start + 1 );


end
%Generic Wave
%[t ECG, P_wave QRS_wave T_wave] = create_ECG(0.25, 0.2, 1.6, 0.40, 0.3, 0.16, 0.4, 0.1, 0.11, 0.09, 80);
